"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LINE = exports.COLOR = exports.STRING = exports.IDENT = exports.PERCENT = exports.ANGLE = exports.UNSUPPORTED_LENGTH_UNIT = exports.LENGTH = exports.NUMBER = exports.AUTO = exports.NONE = exports.WORD = exports.COMMA = exports.SLASH = exports.SPACE = exports.regExpToken = void 0;

var _postcssValueParser = require("postcss-value-parser");

var _cssColorKeywords = _interopRequireDefault(require("css-color-keywords"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var matchString = function matchString(node) {
  if (node.type !== 'string') return null;
  return node.value.replace(/\\([0-9a-f]{1,6})(?:\s|$)/gi, function (match, charCode) {
    return String.fromCharCode(parseInt(charCode, 16));
  }).replace(/\\/g, '');
};

var hexColorRe = /^(#(?:[0-9a-f]{3,4}){1,2})$/i;
var cssFunctionNameRe = /^(rgba?|hsla?|hwb|lab|lch|gray|color)$/;

var matchColor = function matchColor(node) {
  if (node.type === 'word' && (hexColorRe.test(node.value) || node.value in _cssColorKeywords["default"] || node.value === 'transparent')) {
    return node.value;
  } else if (node.type === 'function' && cssFunctionNameRe.test(node.value)) {
    return (0, _postcssValueParser.stringify)(node);
  }

  return null;
};

var noneRe = /^(none)$/i;
var autoRe = /^(auto)$/i;
var identRe = /(^-?[_a-z][_a-z0-9-]*$)/i; // Note if these are wrong, you'll need to change index.js too

var numberRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?)$/i; // Note lengthRe is sneaky: you can omit units for 0

var lengthRe = /^(0$|(?:[+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?)(?=px$))/i;
var unsupportedUnitRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?(ch|em|ex|rem|vh|vw|vmin|vmax|cm|mm|in|pc|pt))$/i;
var angleRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?(?:deg|rad))$/i;
var percentRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?%)$/i;

var noopToken = function noopToken(predicate) {
  return function (node) {
    return predicate(node) ? '<token>' : null;
  };
};

var valueForTypeToken = function valueForTypeToken(type) {
  return function (node) {
    return node.type === type ? node.value : null;
  };
};

var regExpToken = function regExpToken(regExp) {
  var transform = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : String;
  return function (node) {
    if (node.type !== 'word') return null;
    var match = node.value.match(regExp);
    if (match === null) return null;
    var value = transform(match[1]);

    if (/px/.test(node.value)) {
      return "scalePx2dp(".concat(value, ")");
    } else {
      return value;
    }
  };
};

exports.regExpToken = regExpToken;
var SPACE = noopToken(function (node) {
  return node.type === 'space';
});
exports.SPACE = SPACE;
var SLASH = noopToken(function (node) {
  return node.type === 'div' && node.value === '/';
});
exports.SLASH = SLASH;
var COMMA = noopToken(function (node) {
  return node.type === 'div' && node.value === ',';
});
exports.COMMA = COMMA;
var WORD = valueForTypeToken('word');
exports.WORD = WORD;
var NONE = regExpToken(noneRe);
exports.NONE = NONE;
var AUTO = regExpToken(autoRe);
exports.AUTO = AUTO;
var NUMBER = regExpToken(numberRe, Number);
exports.NUMBER = NUMBER;
var LENGTH = regExpToken(lengthRe, Number);
exports.LENGTH = LENGTH;
var UNSUPPORTED_LENGTH_UNIT = regExpToken(unsupportedUnitRe);
exports.UNSUPPORTED_LENGTH_UNIT = UNSUPPORTED_LENGTH_UNIT;
var ANGLE = regExpToken(angleRe, function (angle) {
  return angle.toLowerCase();
});
exports.ANGLE = ANGLE;
var PERCENT = regExpToken(percentRe);
exports.PERCENT = PERCENT;
var IDENT = regExpToken(identRe);
exports.IDENT = IDENT;
var STRING = matchString;
exports.STRING = STRING;
var COLOR = matchColor;
exports.COLOR = COLOR;
var LINE = regExpToken(/^(none|underline|line-through)$/i);
exports.LINE = LINE;